# django-pyston

[![Build
Status](https://travis-ci.org/druids/django-pyston.svg?branch=master)](https://travis-ci.org/druids/django-pyston)
[![Licence](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](https://opensource.org/licenses/BSD-3-Clause)

Django-pyston is a library originally created from `django-piston` application
(https://github.com/django-piston/django-piston), but currently the code is fully rewritten. It’s purpose is to help
 with development RESTful applications.


## Documentation

For docs and examples see [http://django-pyston.readthedocs.org/](http://django-pyston.readthedocs.org/).
